import csv
import datetime
import gzip
import json
import os
import socket
import StringIO
import time
import urllib2


from django.conf import settings

LIST_BRANCH_URL = "lp:harvest-data"

def read_csv(url, sock):
    if url.endswith(".csv.gz"):
        data = gzip.GzipFile(fileobj=StringIO.StringIO(sock.read())).readlines()
    else:
        data = sock.readlines()
    lines = filter(lambda a: a.strip()!="", data)
    return [map(unicode, [a for a in l]) for l in csv.reader(lines)]

def read_json(url, sock):
    if url.endswith(".json.gz"):
        data = gzip.GzipFile(fileobj=StringIO.StringIO(sock.read())).read()
    else:
        data = sock.read()
    entries = json.loads(data)
    return entries

def convert_from_csv(entries):
    data = []
    for entry in entries:
        data += [{"source_package": entry[0],
                  "link": entry[1],
                  "short_description": entry[2]}]
    return data

def read_entries(url, last_updated):
    try:
        socket.setdefaulttimeout(5)
        req = urllib2.Request(url)
        sock = urllib2.urlopen(req)
    except:
        return [None, None]

    datetime_lm = None
    data = None
    if sock.info().has_key("Last-Modified") and sock.info()["Last-Modified"]:
        lm_string = sock.info()["Last-Modified"]
        if lm_string:
            timestamp_lm = time.mktime(time.strptime(lm_string, 
                                                     "%a, %d %b %Y %H:%M:%S GMT"))
            datetime_lm = datetime.datetime.utcfromtimestamp(timestamp_lm)
    if last_updated and datetime_lm and datetime_lm <= last_updated:
        sock.close()
        return [None,None]

    if url.endswith(".csv") or url.endswith(".csv.gz"):
        data = convert_from_csv(read_csv(url, sock))
    if url.endswith(".json") or url.endswith(".json.gz"):
        data = read_json(url, sock)
    sock.close()
    return (data, datetime_lm)

def unify_list_entry(entry):
    for e in entry:
        e = unicode(e.strip())
    # only contains url and short description
    if len(entry) == 2:
        entry.extend([None])
    return entry

def read_lists(list_dir):
    list_file = os.path.join(list_dir, "opportunities")
    if not os.path.exists(list_file):
        return []
    lines = open(list_file).readlines()
    
    # comment out empty entries, or entries that were commented out
    lines = filter(lambda b: b.strip() != "" and not b.startswith("#"), lines)
    
    csv_entries = [l for l in csv.reader(lines)]
    entries = map(unify_list_entry, csv_entries)
    return entries


def pull_lists(data_dir):
    list_dir = settings.LIST_PATH
    old_bzr_log = None
    new_bzr_log = os.path.join(settings.DATA_PATH, ".bzr.log")
    if not os.environ.has_key("BZR_LOG"):
        os.environ["BZR_LOG"] = new_bzr_log
    else:
        old_bzr_log = os.environ["BZR_LOG"]
    try:
        if not os.path.exists(list_dir):
            os.system("cd %s; bzr checkout %s lists -q" % (data_dir, LIST_BRANCH_URL))
        else:
            os.system("cd %s; bzr update -q" % list_dir)
    finally:
        if not old_bzr_log:
            os.environ.pop("BZR_LOG")
    return list_dir
