from django.contrib.auth import logout
from django.contrib.auth.models import User
from django.db.models import F
from django.http import HttpResponseRedirect
from django.shortcuts import render_to_response
from django.template import RequestContext
from django.core.cache import cache

from opportunities.models import SourcePackage, OpportunityList, Opportunity, Note

def index(request):
    values = cache.get_many(['user_count', 'source_packages',
        'opp_lists', 'opp', 'notes'])
    if 'user_count' not in values:
        values['user_count'] = User.objects.count()
        cache.set('user_count', values['user_count'], 60 * 5)
    if 'source_packages' not in values:
        values['source_packages'] = SourcePackage.objects.count()
        cache.set('source_packages', values['source_packages'], 60 * 5)
    if 'opp_lists' not in values:
        values['opp_lists'] = OpportunityList.objects.filter(active=True).count()
        cache.set('opp_lists', values['opp_lists'], 60 * 5)
    if 'opp' not in values:
        values['opp'] = Opportunity.objects.only_valid().count()
        cache.set('opp', values['opp'], 60 * 5)
    if 'notes' not in values:
        values['notes'] = Note.objects.count()
        cache.set('notes', values['notes'], 60 * 5)
    context = { 
        'pageSection': 'home', 
        'users': values['user_count'],
        'sourcepackages': values['source_packages'],
        'opportunitylists': values['opp_lists'],
        'opportunities': values['opp'],
        'notes': values['notes'],
    }
    return render_to_response('index.html', context,
                              context_instance=RequestContext(request))

def doc(request):
    return render_to_response('doc.html', {}, context_instance=RequestContext(request))

def site_logout(request):
    logout(request)
    return HttpResponseRedirect('/')

