from django.contrib.syndication.feeds import Feed
#When Django 1.2 is available, change to new feed API: from django.contrib.syndication.views import Feed
from django.core.urlresolvers import reverse
from django.core.exceptions import ObjectDoesNotExist
from django.shortcuts import get_object_or_404
from django.utils.translation import ugettext_lazy as _
from django.utils.translation import string_concat

import models

class _OpportunitiesFeed(Feed):
	def item_title(self, opp):
		return _("%(sourcepackage)s: %(description)s") % (opp.sourcepackage.name, opp.description)
	
	def item_description(self, opp):
		#this is equivalent to the template opportunities/include/opportunity.html.
		summary_str = ""
		if len(opp.summary) > 0:
			#join the strings so they are translated at the right time (not now)
			summary_str = opp.summary[0]
			for s in opp.summary[1:]:
				summary_str = string_concat(summary_str, _(", "), s)
		return summary_str
	
	def item_link(self, opp):
		return opp.url
	
	def item_guid(self, opp):
		return opp.url
	
	def item_pubdate(self, opp):
		return opp.since

class NewestOpportunitiesFeed(_OpportunitiesFeed):
	def title(self):
		return _("Newest opportunities in Harvest")
	
	def link(self):
		return reverse('filter')
	
	def items(self):
		valid_opps = models.Opportunity.objects.only_valid().order_by('-last_updated')[:25]
		if (valid_opps):
			return valid_opps
		else:
			return []

class SinglePackageFeed(_OpportunitiesFeed):
	def get_object(self, bits):
		if len(bits) != 1:
			raise ObjectDoesNotExist
		return get_object_or_404(models.SourcePackage, name=bits[0])
	
	def title(self, pkg):
		return _("Opportunities for %s in Harvest") % pkg.name
	
	def link(self, pkg):
		return reverse('single_package', args=[pkg.name])
	
	def items(self, pkg):
		return pkg.opportunity_set.only_valid().order_by('-last_updated')
	
	def item_title(self, opp):
		return opp.description
