#!/usr/bin/python

import os
import sys

from django.conf import settings
from django.core.management.base import NoArgsCommand
from django.db import transaction

from common import opportunity_lists
from common.utils import instantiate_logger
from opportunities.models import OpportunityList

class Command(NoArgsCommand):
    help = "Pull opportunity lists and update them in the DB."

    def update_lists(self):
        logger = instantiate_logger(os.path.splitext(os.path.basename(__file__))[0])
        data_dir = settings.DATA_PATH
        if not os.path.exists(data_dir):
            os.makedirs(data_dir)
        logger.debug("Pulling lists.")
        list_dir = opportunity_lists.pull_lists(data_dir)
        for l in OpportunityList.objects.all():
            l.active = False
            l.save()
        for (list_url, 
             list_description, 
             list_explanation) in opportunity_lists.read_lists(list_dir):
            logger.debug("Adding/updating record for %s." % list_url)
            op_list, created = OpportunityList.objects.get_or_create(url=list_url)
            op_list.description = list_description
            if list_explanation:
                op_list.explanation = list_explanation
            op_list.active = True
            op_list.name = self.chop_name(list_url)
            op_list.save()
            logger.debug("Wrote record for %s." % op_list.name)
        logger.debug("Completed.")

    def chop_name(self, list_url):
        filename = os.path.basename(list_url)
        for extension in [ ".csv", ".csv.gz", ".cgi", ".json", ".json.gz" ]:
            filename = filename.rsplit(extension)[0]
        return filename

    def handle_noargs(self, **options):
        transaction.enter_transaction_management()
        try:
            if not settings.PROJECT_PATH:
                print >> sys.stderr, "PROJECT_PATH not set."
                sys.exit(1)
            transaction.managed(True)
            try:
                self.update_lists()
            except:
                transaction.rollback()
                raise
            else:
                transaction.commit()
            finally:
                transaction.managed(False)
        finally:
            transaction.leave_transaction_management()
