#!/usr/bin/python

import os
import sys

from django.conf import settings
from django.core.management.base import NoArgsCommand
from django.db import transaction

from common import opportunity_lists
from common.utils import instantiate_logger
from opportunities import models

class Command(NoArgsCommand):
    help = "Pull opportunity lists and update them in the DB."

    def update_lists(self):
        logger = instantiate_logger(os.path.splitext(os.path.basename(__file__))[0])
        for op_list in models.OpportunityList.objects.filter(active=True):
            logger.debug("Checking opportunity list %s" % op_list.url)
            (entries, new_date) = opportunity_lists.read_entries(op_list.url, op_list.last_updated)
            if entries:
                logger.debug("Has entries and was updated at %s." % new_date)
                op_list.last_updated = new_date
                for entry in entries:
                    sp, created = models.SourcePackage.objects.get_or_create(name=entry["source_package"])
                    try:
                        opportunity = models.Opportunity.objects.get(description=str(entry["short_description"]),
                                                          url=entry["link"], sourcepackage=sp,
                                                          opportunitylist=op_list)
                    except models.Opportunity.DoesNotExist:
                        opportunity = models.Opportunity(description=str(entry["short_description"]),
                                                         url=entry["link"], sourcepackage=sp,
                                                         since=op_list.last_updated,
                                                         opportunitylist=op_list,
                                                         experience=op_list.experience)
                    opportunity.last_updated = op_list.last_updated
                    if entry.has_key("description"):
                        opportunity.long_description = unicode(entry["description"])
                    if entry.has_key("severity"):
                        opportunity.severity = entry["severity"]
                    opportunity.valid = True
                    opportunity.save()
            else:
                if new_date:
                    op_list.active = False
            
            if op_list.experience:
                opportunities = models.Opportunity.objects.filter(opportunitylist=op_list, 
                                                                  experience=0)
                for opportunity in opportunities:
                    opportunity.experience = op_list.experience
                    opportunity.save()
            op_list.save()
            logger.debug("%s updated." % op_list.url)
        logger.debug("Completed.")

    def handle_noargs(self, **options):
        transaction.enter_transaction_management()
        try:
            if not settings.PROJECT_PATH:
                print >> sys.stderr, "PROJECT_PATH not set."
                sys.exit(1)
            transaction.managed(True)
            try:
                self.update_lists()
            except:
                transaction.rollback()
                raise
            else:
                transaction.commit()
            finally:
                transaction.managed(False)
        finally:
            transaction.leave_transaction_management()

