#!/usr/bin/python

import os
import sys

from django.core.management.base import NoArgsCommand

from common import launchpad
from common.utils import instantiate_logger
from opportunities.models import SourcePackage, PackageSet

class Command(NoArgsCommand):
    help = "Pull packageset information from Launchpad."

    def handle_noargs(self, **options):
        logger = instantiate_logger(os.path.splitext(os.path.basename(__file__))[0])
        logger.debug("Logging into Launchpad.")
        lp = launchpad.lp_login()
        if not lp:
            sys.exit(1)
        logger.debug("Succeed logging in. Getting packagesets.")
        lp_packagesets = launchpad.get_packagesets(lp)
        logger.debug("Packagesets retrieved.")
        package_mapping = {}
        logger.debug("Checking if packagesets need to be created in Harvest.")
        unseeded, created = PackageSet.objects.get_or_create(name="unseeded")
        if created:
            logger.debug("'unseeded' packageset created.")
            unseeded.save()
        for lp_packageset in lp_packagesets:
            packageset, created = PackageSet.objects.get_or_create(name=lp_packageset.name)
            if created:
                logger.debug("'%s' packageset created." % lp_packageset.name)
                packageset.save()
            logger.debug("Finding out which package is in %s." % lp_packageset.name)
            # record information which package is in which package sets
            for package_name in lp_packageset.getSourcesIncluded():
                if not package_mapping.has_key(package_name):
                    package_mapping[package_name] = set()
                package_mapping[package_name].add((lp_packageset.name))
        logger.debug("Updating packageset information for all packages.")
        for package_name in package_mapping.keys():
            try:
                package = SourcePackage.objects.get(name=package_name)
            except SourcePackage.DoesNotExist:
                package = None
            if package:
                for packageset_name in package_mapping[package_name]:
                    try:
                        package.packagesets.get(name=packageset_name)
                    except PackageSet.DoesNotExist:
                        package.packagesets.add(PackageSet.objects.get(name=packageset_name))
                # if package is in mapping, it can't be in the unseeded
                # list any more
                if package.packagesets.filter(name="unseeded"):
                    package.packagesets.remove(unseeded)
                for packageset in package.packagesets.all():
                    if packageset.name not in package_mapping[package_name]:
                        package.packagesets.remove(packageset)
                package.save()
        unseeded_packages = SourcePackage.objects.filter(packagesets__isnull=True)
        for u in unseeded_packages:
            u.packagesets.add(unseeded)
            u.save()
        logger.debug("Completed.")
