# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):
    
    def forwards(self, orm):
        
        # Adding model 'PackageSet'
        db.create_table('opportunities_packageset', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.SlugField')(max_length=40, db_index=True)),
        ))
        db.send_create_signal('opportunities', ['PackageSet'])

        # Adding model 'SourcePackage'
        db.create_table('opportunities_sourcepackage', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.SlugField')(max_length=70, db_index=True)),
        ))
        db.send_create_signal('opportunities', ['SourcePackage'])

        # Adding M2M table for field packagesets on 'SourcePackage'
        db.create_table('opportunities_sourcepackage_packagesets', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('sourcepackage', models.ForeignKey(orm['opportunities.sourcepackage'], null=False)),
            ('packageset', models.ForeignKey(orm['opportunities.packageset'], null=False))
        ))
        db.create_unique('opportunities_sourcepackage_packagesets', ['sourcepackage_id', 'packageset_id'])

        # Adding model 'OpportunityList'
        db.create_table('opportunities_opportunitylist', (
            ('last_updated', self.gf('django.db.models.fields.DateTimeField')(null=True)),
            ('description', self.gf('django.db.models.fields.TextField')(max_length=350)),
            ('url', self.gf('django.db.models.fields.URLField')(max_length=200)),
            ('explanation', self.gf('django.db.models.fields.URLField')(max_length=500, null=True)),
            ('commentable', self.gf('django.db.models.fields.BooleanField')(default=True, blank=True)),
            ('experience', self.gf('django.db.models.fields.IntegerField')(default=0)),
            ('featured', self.gf('django.db.models.fields.BooleanField')(default=False, blank=True)),
            ('active', self.gf('django.db.models.fields.BooleanField')(default=True, blank=True)),
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.SlugField')(max_length=70, db_index=True)),
        ))
        db.send_create_signal('opportunities', ['OpportunityList'])

        # Adding model 'Opportunity'
        db.create_table('opportunities_opportunity', (
            ('applied', self.gf('django.db.models.fields.BooleanField')(default=False, blank=True)),
            ('last_updated', self.gf('django.db.models.fields.DateTimeField')(null=True)),
            ('description', self.gf('django.db.models.fields.TextField')(max_length=350)),
            ('url', self.gf('django.db.models.fields.URLField')(max_length=350)),
            ('since', self.gf('django.db.models.fields.DateTimeField')(null=True)),
            ('experience', self.gf('django.db.models.fields.IntegerField')(default=0)),
            ('reviewed', self.gf('django.db.models.fields.BooleanField')(default=False, blank=True)),
            ('valid', self.gf('django.db.models.fields.BooleanField')(default=True, blank=True)),
            ('opportunitylist', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['opportunities.OpportunityList'])),
            ('sourcepackage', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['opportunities.SourcePackage'])),
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
        ))
        db.send_create_signal('opportunities', ['Opportunity'])

        # Adding model 'Note'
        db.create_table('opportunities_note', (
            ('date', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
            ('text', self.gf('django.db.models.fields.CharField')(max_length=250)),
            ('opportunity', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['opportunities.Opportunity'])),
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('author', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['auth.User'])),
        ))
        db.send_create_signal('opportunities', ['Note'])

        # Adding model 'ActionLogEntry'
        db.create_table('opportunities_actionlogentry', (
            ('action', self.gf('django.db.models.fields.TextField')(max_length=200)),
            ('timestamp', self.gf('django.db.models.fields.DateTimeField')()),
            ('who', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['auth.User'])),
            ('opportunity', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['opportunities.Opportunity'], blank=True)),
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
        ))
        db.send_create_signal('opportunities', ['ActionLogEntry'])
    
    
    def backwards(self, orm):
        
        # Deleting model 'PackageSet'
        db.delete_table('opportunities_packageset')

        # Deleting model 'SourcePackage'
        db.delete_table('opportunities_sourcepackage')

        # Removing M2M table for field packagesets on 'SourcePackage'
        db.delete_table('opportunities_sourcepackage_packagesets')

        # Deleting model 'OpportunityList'
        db.delete_table('opportunities_opportunitylist')

        # Deleting model 'Opportunity'
        db.delete_table('opportunities_opportunity')

        # Deleting model 'Note'
        db.delete_table('opportunities_note')

        # Deleting model 'ActionLogEntry'
        db.delete_table('opportunities_actionlogentry')
    
    
    models = {
        'auth.group': {
            'Meta': {'object_name': 'Group'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '80'}),
            'permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'})
        },
        'auth.permission': {
            'Meta': {'unique_together': "(('content_type', 'codename'),)", 'object_name': 'Permission'},
            'codename': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        },
        'auth.user': {
            'Meta': {'object_name': 'User'},
            'date_joined': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'groups': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Group']", 'symmetrical': 'False', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True', 'blank': 'True'}),
            'is_staff': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'blank': 'True'}),
            'is_superuser': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'blank': 'True'}),
            'last_login': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'user_permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'}),
            'username': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '30'})
        },
        'contenttypes.contenttype': {
            'Meta': {'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'opportunities.actionlogentry': {
            'Meta': {'object_name': 'ActionLogEntry'},
            'action': ('django.db.models.fields.TextField', [], {'max_length': '200'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'opportunity': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['opportunities.Opportunity']", 'blank': 'True'}),
            'timestamp': ('django.db.models.fields.DateTimeField', [], {}),
            'who': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.User']"})
        },
        'opportunities.note': {
            'Meta': {'object_name': 'Note'},
            'author': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.User']"}),
            'date': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'opportunity': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['opportunities.Opportunity']"}),
            'text': ('django.db.models.fields.CharField', [], {'max_length': '250'})
        },
        'opportunities.opportunity': {
            'Meta': {'object_name': 'Opportunity'},
            'applied': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'blank': 'True'}),
            'description': ('django.db.models.fields.TextField', [], {'max_length': '350'}),
            'experience': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'last_updated': ('django.db.models.fields.DateTimeField', [], {'null': 'True'}),
            'opportunitylist': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['opportunities.OpportunityList']"}),
            'reviewed': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'blank': 'True'}),
            'since': ('django.db.models.fields.DateTimeField', [], {'null': 'True'}),
            'sourcepackage': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['opportunities.SourcePackage']"}),
            'url': ('django.db.models.fields.URLField', [], {'max_length': '350'}),
            'valid': ('django.db.models.fields.BooleanField', [], {'default': 'True', 'blank': 'True'})
        },
        'opportunities.opportunitylist': {
            'Meta': {'object_name': 'OpportunityList'},
            'active': ('django.db.models.fields.BooleanField', [], {'default': 'True', 'blank': 'True'}),
            'commentable': ('django.db.models.fields.BooleanField', [], {'default': 'True', 'blank': 'True'}),
            'description': ('django.db.models.fields.TextField', [], {'max_length': '350'}),
            'experience': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'explanation': ('django.db.models.fields.URLField', [], {'max_length': '500', 'null': 'True'}),
            'featured': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'last_updated': ('django.db.models.fields.DateTimeField', [], {'null': 'True'}),
            'name': ('django.db.models.fields.SlugField', [], {'max_length': '70', 'db_index': 'True'}),
            'url': ('django.db.models.fields.URLField', [], {'max_length': '200'})
        },
        'opportunities.packageset': {
            'Meta': {'object_name': 'PackageSet'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.SlugField', [], {'max_length': '40', 'db_index': 'True'})
        },
        'opportunities.sourcepackage': {
            'Meta': {'object_name': 'SourcePackage'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.SlugField', [], {'max_length': '70', 'db_index': 'True'}),
            'packagesets': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['opportunities.PackageSet']", 'null': 'True', 'symmetrical': 'False'})
        }
    }
    
    complete_apps = ['opportunities']
